@@ -111,6 +111,8 @@ double CPUtime2();
 double jobtime();                                                                //   " include all threads + subprocesses
 void compact_time(const time_t DT, char *compactDT);                             //  time_t DT to yyyymmddhhmmss
 void pretty_datetime(const time_t DT, char *prettyDT);                           //  time_t DT to yyyy-mm-dd hh:mm:ss
+void secs_datetime(double secs, int datetime[6]);                                //  seconds to year/mon/day/hour/min/secs
+void datetime_secs(int datetime[6], double *secs);                               //  year/mon/day/hour/min/secs to seconds
 int  parseprocfile(cchar *pfile, cchar *pname, double *value, ...);              //  get data from /proc file
 int  parseprocrec(char *prec, int field, double *value, ...);                    //  get data from /proc file record
 int  coretemp();                                                                 //  get CPU temperature (package temp)
@@ -185,7 +187,7 @@ int  strTrim(char *dest, cchar *source);
 int  strTrim(char *string);                                                      //  remove trailing blanks
 int  strTrim2(char *dest, cchar *source);                                        //  remove leading and trailing blanks
 int  strTrim2(char *string);                                                     //  remove leading and trailing blanks
-int  strCompress(char *dest, cchar *source);                                     //  remove all blanks incl. imbedded
+int  strCompress(char *dest, cchar *source);                                     //  remove all blanks incl. embedded
 int  strCompress(char *string);                                                  //  remove all blanks
 int  strncatv(char *dest, int maxcc, cchar *source, ...);                        //  catenate strings (last = null)
 int  strmatchV(cchar *string, ...);                                              //  compare to N strings, return 1-N or 0
